@@ -10,7 +10,7 @@ use Exporter 'import';
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2024-02-25'; # DATE
 our $DIST = 'App-BPOMUtils-RPO-Ingredients'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 our @EXPORT_OK = qw(
                        bpom_rpo_ingredients_group_for_label
@@ -29,23 +29,23 @@ $SPEC{bpom_rpo_ingredients_group_for_label} = {
 
 This utility accepts a CSV data from stdin. The CSV must be formatted like this:
 
-    Ingredient,%weight,"Ingredient name for label (Indonesian)","Ingredient name for label (English)","Ingredient group for label (Indonesian)","Ingredient group for label (English)"
+    Ingredient,%weight,"Ingredient name for label (Indonesian)","Ingredient name for label (English)","QUID?","Note (Indonesian)","Note (English)","Ingredient group for label (Indonesian)","Ingredient group for label (English)"
     Air,78.48,Air,Water,,
-    Gula,16.00,Gula,Sugar,,
-    "Nata de coco",5.00,"Nata de coco 3%","Nata de coco 3%",,
-    "Asam sitrat",0.25,"Asam sitrat","Citric acid","Pengatur keasaman","Acidity regulator"
-    "Asam malat",0.10,"Asam malat","Malic acid","Pengatur keasaman","Acidity regulator"
-    "Grape flavor",0.10,Anggur,Grape,"Perisa sintetik","Synthetic flavoring"
-    "Tea flavor",0.05,Teh,Tea,"Perisa sintetik","Synthetic flavoring"
-    "Natrium benzoat",0.02,"Natrium benzoat","Sodium benzoate",Pengawet,Preservative
+    Gula,16.00,Gula,Sugar,,"mengandung pengawet sulfit","contains sulfite preservative",
+    "Nata de coco",5.00,"Nata de coco","Nata de coco",1,"mengandung pengawet sulfit","contains sulfit preservative",
+    "Asam sitrat",0.25,"Asam sitrat","Citric acid",,,,"Pengatur keasaman","Acidity regulator"
+    "Asam malat",0.10,"Asam malat","Malic acid",,,,"Pengatur keasaman","Acidity regulator"
+    "Grape flavor",0.10,Anggur,Grape,,,,"Perisa sintetik","Synthetic flavoring"
+    "Tea flavor",0.05,Teh,Tea,,,,"Perisa sintetik","Synthetic flavoring"
+    "Natrium benzoat",0.02,"Natrium benzoat","Sodium benzoate",,,,Pengawet,Preservative
 
 It can then group the ingredients based on the ingredient group and generate
 this (for Indonesian, `--lang ind`):
 
     Ingredient,%weight
     Air,78.48
-    Gula,16.00
-    "Nata de coco 3%",5.00
+    Gula (mengandung pengawet sulfit),16.00
+    "Nata de coco 5% (mengandung pengawet sulfit)",5.00
     "Pengatur keasaman (Asam sitrat, Asam malat)",0.35
     "Perisa sintetik (Anggur, Teh)",0.15
     "Pengawet Natrium benzoat",0.02
@@ -54,8 +54,8 @@ And for English, `--lang eng`:
 
     Ingredient,%weight
     Water,78.48
-    Sugar,16.00
-    "Nata de coco 3%",5.00
+    Sugar (contains sulfite preservative),16.00
+    "Nata de coco 5% (contains sulfite preservative)",5.00
     "Acidity regulator (Citric acid, Malic acid)",0.35
     "Synthetic flavoring (Grape, Tea)",0.15
     "Preservative Sodium benzoate",0.02
@@ -81,8 +81,16 @@ sub bpom_rpo_ingredients_group_for_label {
     my %ingredients; # key = name, value = { weight=>, items=> }
     for my $n (1 .. $#rows) {
         my $row = $rows[$n];
-        my ($ingredient0, $weight, $ind_ingredient, $eng_ingredient, $ind_group, $eng_group) = @$row;
-        my ($label_ingredient, $group) = $args{lang} eq 'eng' ? ($eng_ingredient, $eng_group) : ($ind_ingredient, $ind_group);
+        my ($ingredient0, $weight, $ind_ingredient, $eng_ingredient, $quid, $ind_note, $eng_note, $ind_group, $eng_group) = @$row;
+        my ($label_ingredient0, $note, $group) = $args{lang} eq 'eng' ? ($eng_ingredient, $eng_note, $eng_group) : ($ind_ingredient, $ind_note, $ind_group);
+
+        my $label_ingredient = join(
+            " ",
+            $label_ingredient0,
+            ($quid ? (sprintf "%g%%", $weight) : ()),
+            ($note ? ("($note)") : ()),
+        );
+
         my $has_group;
         if ($group) { $has_group++ } else { $group = $label_ingredient }
         $weights{$ingredient0} = $weight;
@@ -131,7 +139,7 @@ App::BPOMUtils::RPO::Ingredients - Group ingredients suitable for food label
 
 =head1 VERSION
 
-This document describes version 0.003 of App::BPOMUtils::RPO::Ingredients (from Perl distribution App-BPOMUtils-RPO-Ingredients), released on 2024-02-25.
+This document describes version 0.004 of App::BPOMUtils::RPO::Ingredients (from Perl distribution App-BPOMUtils-RPO-Ingredients), released on 2024-02-25.
 
 =head1 SYNOPSIS
 
@@ -160,23 +168,23 @@ Group ingredients suitable for food label.
 
 This utility accepts a CSV data from stdin. The CSV must be formatted like this:
 
- Ingredient,%weight,"Ingredient name for label (Indonesian)","Ingredient name for label (English)","Ingredient group for label (Indonesian)","Ingredient group for label (English)"
+ Ingredient,%weight,"Ingredient name for label (Indonesian)","Ingredient name for label (English)","QUID?","Note (Indonesian)","Note (English)","Ingredient group for label (Indonesian)","Ingredient group for label (English)"
  Air,78.48,Air,Water,,
- Gula,16.00,Gula,Sugar,,
- "Nata de coco",5.00,"Nata de coco 3%","Nata de coco 3%",,
- "Asam sitrat",0.25,"Asam sitrat","Citric acid","Pengatur keasaman","Acidity regulator"
- "Asam malat",0.10,"Asam malat","Malic acid","Pengatur keasaman","Acidity regulator"
- "Grape flavor",0.10,Anggur,Grape,"Perisa sintetik","Synthetic flavoring"
- "Tea flavor",0.05,Teh,Tea,"Perisa sintetik","Synthetic flavoring"
- "Natrium benzoat",0.02,"Natrium benzoat","Sodium benzoate",Pengawet,Preservative
+ Gula,16.00,Gula,Sugar,,"mengandung pengawet sulfit","contains sulfite preservative",
+ "Nata de coco",5.00,"Nata de coco","Nata de coco",1,"mengandung pengawet sulfit","contains sulfit preservative",
+ "Asam sitrat",0.25,"Asam sitrat","Citric acid",,,,"Pengatur keasaman","Acidity regulator"
+ "Asam malat",0.10,"Asam malat","Malic acid",,,,"Pengatur keasaman","Acidity regulator"
+ "Grape flavor",0.10,Anggur,Grape,,,,"Perisa sintetik","Synthetic flavoring"
+ "Tea flavor",0.05,Teh,Tea,,,,"Perisa sintetik","Synthetic flavoring"
+ "Natrium benzoat",0.02,"Natrium benzoat","Sodium benzoate",,,,Pengawet,Preservative
 
 It can then group the ingredients based on the ingredient group and generate
 this (for Indonesian, C<--lang ind>):
 
  Ingredient,%weight
  Air,78.48
- Gula,16.00
- "Nata de coco 3%",5.00
+ Gula (mengandung pengawet sulfit),16.00
+ "Nata de coco 5% (mengandung pengawet sulfit)",5.00
  "Pengatur keasaman (Asam sitrat, Asam malat)",0.35
  "Perisa sintetik (Anggur, Teh)",0.15
  "Pengawet Natrium benzoat",0.02
@@ -185,8 +193,8 @@ And for English, C<--lang eng>:
 
  Ingredient,%weight
  Water,78.48
- Sugar,16.00
- "Nata de coco 3%",5.00
+ Sugar (contains sulfite preservative),16.00
+ "Nata de coco 5% (contains sulfite preservative)",5.00
  "Acidity regulator (Citric acid, Malic acid)",0.35
  "Synthetic flavoring (Grape, Tea)",0.15
  "Preservative Sodium benzoate",0.02
